@@ -64,7 +64,7 @@ class CodeContext:
         else:
             self.obj_list.insert(0, md_obj)
 
-    def md_obj(self, javascript_path: Path) -> MdObj:
+    def md_obj(self, page_path: Path, javascript_path: Path) -> MdObj:
         """
         Return the markdown object that represents output and code.
 
@@ -98,6 +98,7 @@ class CodeContext:
                 return (
                     Admonition(
                         code_final,
+                        page_path=page_path,
                         javascript_path=javascript_path,
                         collapse=True,
                         title="Code",
@@ -113,6 +114,7 @@ class CodeContext:
                     content
                     + Admonition(
                         code_final,
+                        page_path=page_path,
                         javascript_path=javascript_path,
                         collapse=True,
                         title="Code",
